::: spotify.api.API
    options:
      members:
        - get_current_users_profile
        - get_users_top_items
        - get_users_profile
        - follow_playlist
        - unfollow_playlist
        - get_followed_artists
        - follow_artists_or_users
        - unfollow_artists_or_users
        - check_if_user_follows_artists_or_users
        - check_if_current_user_follows_playlist
::: spotify.models.SimpleUser
::: spotify.models.User
::: spotify.models.OwnUser
::: spotify.models.ExplicitContent
